@@ -22,7 +22,8 @@
 #include <ncurses.h>
 #include "libacpi.h"
 
-int get_cpu_cur(){
+int get_cpu_cur()
+{
     FILE *cpuinfo;
     int freq=0;
     if((cpuinfo=fopen("/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq","r"))==NULL){
@@ -33,7 +34,8 @@ int get_cpu_cur(){
     return freq;
 }
 
-int get_cpu_max(){
+int get_cpu_max()
+{
     FILE *cpuinfo;
     int freq=0;
     if((cpuinfo=fopen("/sys/devices/system/cpu/cpu0/cpufreq/scaling_max_freq","r"))==NULL){
@@ -44,7 +46,8 @@ int get_cpu_max(){
     return freq;
 }
 
-char *get_cpu_gov(){
+char *get_cpu_gov()
+{
     FILE *cpuinfo;
     char buffer[128];
     char *error="not supported";
