@@ -1,5 +1,5 @@
-/* acpi application yacpi 2.0 
- * Copyright (C) 2005 Nico Golde <nico@ngolde.de>
+/* acpi application yacpi
+ * Copyright (C) 2005-2006 Nico Golde <nico@ngolde.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ static struct option long_options[] = {
   {"samples", 1, NULL, 's'},
   {"text", 0, NULL, 't'},
   {"loop", 0, NULL, 'l'},
-  {"delay", 0, NULL, 'd'},
+  {"delay", 1, NULL, 'd'},
   {"multiple", 0, NULL, 'm'},
   {NULL, 0, NULL, 0}
 };
@@ -61,11 +61,6 @@ void helpbox (int x1, int y1, int x2, int y2)
   attroff (WA_REVERSE);
 }
 
-/*********************************************
- * get value for repeat the screen resfresh 
- *  will be fully implemented in the future
- *********************************************
-*/
 int monitor_help (void)
 {
   int rval;
@@ -111,7 +106,7 @@ int samples_help (void)
 
 void help (void)
 {
-  int centerx, centery;         /* Screen center x/y coordinate. */
+  int centerx, centery;
   int userinput;
   int offset = 13;
   int offsetstr = 11;
@@ -204,7 +199,7 @@ void print_window (void)
     mvaddch (0, i, ' ');
     mvaddch (LINES - 1, i, ' ');
   }
-  mvaddstr (0, 0, "* YACPI 2.0 by Nico Golde");
+  mvaddstr (0, 0, "* YACPI " VERSION " by Nico Golde");
   mvaddstr (LINES - 1, 0, "ACPI version detected: ");
   mvprintw (LINES - 1, 23, "%d", get_acpi_version ());
 
@@ -214,6 +209,19 @@ void print_window (void)
 
 /* main acpi handling */
 
+char *chargestate(battery_t *binfo){
+  if (binfo->charge_state == CHARGE)
+    return (strdup("charging")); 
+  else if (binfo->charge_state == DISCHARGE)
+    return (strdup("discharging")); 
+  else if (binfo->charge_state == CHARGED)
+    return (strdup("charged"));
+  else if (binfo->charge_state == NOINFO)
+    return (strdup("not supported"));
+  return NULL;
+}
+
+
 int acpi_text_handling (int samplef, int samplev, int mflag)
 {
   int i, j;
@@ -231,7 +239,7 @@ int acpi_text_handling (int samplef, int samplev, int mflag)
 
   if (sampleflag)
     sleep_time = 1000000 / samples;
-  
+
   /* we want to acquire samples over some period of time, so . . . */
   for (i = 0; i < samples + globals->battery_count; i++) {
     if (mflag)
@@ -246,31 +254,33 @@ int acpi_text_handling (int samplef, int samplev, int mflag)
   for (i = 0; i < globals->battery_count; i++) {
     binfo = &batteries[i];
     if (binfo->present){
-      printf ("| %s %3d%% | ", binfo->name, binfo->percentage);
-
-      if (!ap->power == AC)
-        printf ("rtime: %02d:%02d h | ", globals->rtime / 60,
-                globals->rtime % 60);
-      if (ap->power == AC && binfo->charge_time > 0)
-        printf ("rctime: %02d:%02d h | ", binfo->charge_time / 60,
-                binfo->charge_time % 60);
-      if(i<1){
-        if (ap->power == AC)
-          printf ("ac=on | ");
-        else 
-          printf ("ac=off | ");
-        printf ("thermal %dc | ", temperature->temp);
+       printf ("| %s %3d%% ", binfo->name, binfo->percentage);
+       if (!ap->power == AC)
+         printf ("| rtime: %02d:%02d h ", globals->rtime / 60,
+                 globals->rtime % 60);
+       if (ap->power == AC && binfo->charge_time > 0)
+         printf ("| rctime: %02d:%02d h ", binfo->charge_time / 60,
+                 binfo->charge_time % 60);
+       printf("| state: %s ", chargestate(binfo)); 
+    }
+    if(i<1){
+      if (ap->power == AC)
+        printf ("| ac=on | ");
+      else
+        printf ("| ac=off | ");
+      printf ("thermal %dc | ", temperature->temp);
+      if(get_cpu_cur() && get_cpu_max ())
         printf ("cpu: %d/%d mhz | ", get_cpu_cur () / 1000, get_cpu_max () / 1000);   /* get cpu frequency */
-        {
-          char *cpu_gov = get_cpu_gov ();
-      
-          printf ("gov: %s", cpu_gov);    /* get cpu governor */
-          free (cpu_gov);
-        }
+      else
+        printf ("cpu: not supported | ");   /* get cpu frequency */
+      {
+        char *cpu_gov = get_cpu_gov ();
+        printf ("gov: %s", cpu_gov);    /* get cpu governor */
+        free (cpu_gov);
       }
     }
   }
-    return 0;
+  return 0;
 }
 
 void acpi_handling (int samplef, int samplev, int mflag)
@@ -335,33 +345,26 @@ void acpi_handling (int samplef, int samplev, int mflag)
           color_change (binfo->percentage, 0);
           for (battery_loops = 1; battery_loops <= (binfo->percentage / 4); battery_loops++)
             printw ("|");
-          attron (COLOR_PAIR (4));
-  
+          attrset (WA_NORMAL);
+
           for (battery_loops = 1; battery_loops <= 25 - (binfo->percentage / 4); battery_loops++)
             printw (" ");
           printw ("]");
           printw (" %2d%%", binfo->percentage);
-          attroff (COLOR_PAIR (4));
         }
         else
           mvprintw (line, 0, "Battery %s on %2d%%", binfo->name,
                               binfo->percentage);
-         line = line + 2;
-        if (binfo->charge_state == CHARGE)
-          mvprintw (line, 0, "Battery %s: charging   ", binfo->name);
-        else if (binfo->charge_state == DISCHARGE)
-          mvprintw (line, 0, "Battery %s: discharging", binfo->name);
-        else if (binfo->charge_state == CHARGED)
-          mvprintw (line, 0, "Battery %s: charged    ", binfo->name);
-        else if (binfo->charge_state == NOINFO)
-          mvprintw (line, 0, "Battery %s: not supported",binfo->name);
+        line = line + 2;
+        move (line,0); clrtoeol();
+        mvprintw (line, 0, "Battery %s: %s", binfo->name, chargestate(binfo));
         line = line + 2;
         if (globals->rtime >= 0 && ap->power != AC) {
           mvprintw (line, 0, "Remaining time: %02d:%02d h        ",
                     globals->rtime / 60, globals->rtime % 60);
           line = line + 2;
         }
-    
+
         if (ap->power == AC && binfo->charge_time > 0) {
           mvprintw (line, 0, "Rem. charge time: %02d:%02d h",
                     binfo->charge_time / 60, binfo->charge_time % 60);
@@ -378,7 +381,7 @@ void acpi_handling (int samplef, int samplev, int mflag)
         color_change (binfo->percentage, 0);
         for (battery_loops = 1; battery_loops <= (binfo->percentage / 2); battery_loops++)
           printw ("|");
-        attron (COLOR_PAIR (4));
+        attrset(WA_NORMAL);
 
         for (battery_loops = 1; battery_loops <= (50 - binfo->percentage / 2); battery_loops++)
           printw (" ");
@@ -408,7 +411,7 @@ void acpi_handling (int samplef, int samplev, int mflag)
           mvprintw (line, 0, "Battery %s Status: charged    ", binfo->name);
         else if (binfo->charge_state == NOINFO)
           mvprintw (line, 0, "Battery %s Status: not supported", binfo->name);
-    
+
         line = line + 2;
         if (globals->rtime >= 0 && ap->power != AC) {
           mvprintw (line, 0, "Remaining time: %02d:%02d h       ",
@@ -438,7 +441,7 @@ void acpi_handling (int samplef, int samplev, int mflag)
   color_change (temperature->temp, 1);
   move (line, 13);
   printw ("%d", temperature->temp);
-  attron (COLOR_PAIR (4));
+  attrset (WA_NORMAL);
   move (line, 16);
   printw ("degrees C");
   refresh ();
@@ -456,7 +459,7 @@ void show_error (void)
 
 void usage (void)
 {
-  puts ("YACPI 2.0 by Nico Golde <nico@ngolde.de>");
+  puts ("YACPI " VERSION " by Nico Golde <nico@ngolde.de>");
   puts ("usage: yacpi [options]\n"
         "short options:\n"
         "-v    print version number + release date.\n"
@@ -492,7 +495,7 @@ int main (int argc, char *argv[])
       multi_flag = TRUE;
       break;
     case 'v':
-      puts ("YACPI 2.0 by Nico Golde - Released: 16.08.2005\n");
+      puts ("YACPI " VERSION " by Nico Golde - Released: 24.05.2006\n");
       exit (0);
       break;
     case 's':
@@ -514,7 +517,7 @@ int main (int argc, char *argv[])
         refresh_delay = atoi(optarg);
         delay_flag = TRUE;
       }else{
-        printf ("\nThe delay have to be between 1 and 1000 seconds....\n");
+        printf ("\nThe delay has to be between 1 and 1000 seconds....\n");
         return 0;
       }
       break;
@@ -535,7 +538,6 @@ int main (int argc, char *argv[])
     init_pair (3, COLOR_RED, -1);
     init_pair (4, COLOR_WHITE, -1);
 
-    
     acpi_handling (sample_flag, sample_number, multi_flag);
     while (1) {
       if (loop_flag){
@@ -550,6 +552,7 @@ int main (int argc, char *argv[])
             switch(ch){
               case 'q':
                 endwin();
+                puts("");
                 return 0;
                 break;
               default:
@@ -562,7 +565,7 @@ int main (int argc, char *argv[])
       switch (ch) {
       case 'q':
         endwin ();
-        puts("");    
+        puts("");
         return 0;
         break;
       case 'r':
@@ -588,7 +591,6 @@ int main (int argc, char *argv[])
         break;
       }
     }
-
     getch ();
     endwin ();
   }
